# alqueda Library

`alqueda` is a Python library containing various machine learning functions, including neuron training, k-NN, perceptron classifiers, RNNs, CNNs, and more.

## Installation

You can install the library using pip:

```bash
pip install alqueda
